Class: Google::Cloud::PrivateCatalog::V1beta1::GitSource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/privatecatalog/v1beta1/private_catalog.rb

Overview

Defines how to access a Git Source.

Instance Attribute Summary collapse

Instance Attribute Details

#branch ⇒ ::String

Returns The revision branch to use.

Returns:

  • (::String) —

    The revision branch to use.



459
460
461
462
# File 'proto_docs/google/cloud/privatecatalog/v1beta1/private_catalog.rb', line 459

class GitSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#commit ⇒ ::String

Returns The revision commit to use.

Returns:

  • (::String) —

    The revision commit to use.



459
460
461
462
# File 'proto_docs/google/cloud/privatecatalog/v1beta1/private_catalog.rb', line 459

class GitSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#dir ⇒ ::String

Returns Directory, relative to the source root, in which to run the build.

This must be a relative path. If a step's dir is specified and is an absolute path, this value is ignored for that step's execution.

Returns:

  • (::String) —

    Directory, relative to the source root, in which to run the build.

    This must be a relative path. If a step's dir is specified and is an absolute path, this value is ignored for that step's execution.



459
460
461
462
# File 'proto_docs/google/cloud/privatecatalog/v1beta1/private_catalog.rb', line 459

class GitSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#repo ⇒ ::String

Returns Location of the Git repo to build.

Returns:

  • (::String) —

    Location of the Git repo to build.



459
460
461
462
# File 'proto_docs/google/cloud/privatecatalog/v1beta1/private_catalog.rb', line 459

class GitSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tag ⇒ ::String

Returns The revision tag to use.

Returns:

  • (::String) —

    The revision tag to use.



459
460
461
462
# File 'proto_docs/google/cloud/privatecatalog/v1beta1/private_catalog.rb', line 459

class GitSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end